==> ViennaRNA-2.4.2.tar.gz: ViennaRNA-2.4.2/doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "_struct_en", "struct__struct__en.html", null ],
    [ "constrain", "group__data__structures.html#structconstrain", null ],
    [ "COORDINATE", "group__plotting__utils.html#structCOORDINATE", null ],
    [ "duplexT", "group__data__structures.html#structduplexT", null ],
    [ "dupVar", "group__data__structures.html#structdupVar", null ],
    [ "interact", "group__data__structures.html#structinteract", "group__data__structures_structinteract" ],
    [ "node", "group__data__structures.html#structnode", null ],
    [ "Postorder_list", "structPostorder__list.html", null ],
    [ "pu_contrib", "group__data__structures.html#structpu__contrib", "group__data__structures_structpu__contrib" ],
    [ "pu_out", "group__data__structures.html#structpu__out", "group__data__structures_structpu__out" ],
    [ "snoopT", "group__data__structures.html#structsnoopT", null ],
    [ "swString", "structswString.html", null ],
    [ "Tree", "structTree.html", null ],
    [ "TwoDfold_vars", "group__kl__neighborhood__mfe.html#structTwoDfold__vars", "group__kl__neighborhood__mfe_structTwoDfold__vars" ],
    [ "TwoDpfold_vars", "structTwoDpfold__vars.html", "structTwoDpfold__vars" ],
    [ "vrna_basepair_s", "group__data__structures.html#structvrna__basepair__s", null ],
    [ "vrna_bp_stack_s", "group__data__structures.html#structvrna__bp__stack__s", null ],
    [ "vrna_color_s", "group__data__structures.html#structvrna__color__s", null ],
    [ "vrna_command_s", "group__file__utils.html#structvrna__command__s", null ],
    [ "vrna_cpair_s", "group__data__structures.html#structvrna__cpair__s", null ],
    [ "vrna_data_linear_s", "group__data__structures.html#structvrna__data__linear__s", null ],
    [ "vrna_dimer_conc_s", "group__pf__cofold.html#structvrna__dimer__conc__s", "group__pf__cofold_structvrna__dimer__conc__s" ],
    [ "vrna_dimer_pf_s", "group__pf__cofold.html#structvrna__dimer__pf__s", "group__pf__cofold_structvrna__dimer__pf__s" ],
    [ "vrna_dotplot_auxdata_t", "group__plotting__utils.html#structvrna__dotplot__auxdata__t", null ],
    [ "vrna_elem_prob_s", "group__struct__utils.html#structvrna__elem__prob__s", null ],
    [ "vrna_exp_param_s", "group__energy__parameters.html#structvrna__exp__param__s", "group__energy__parameters_structvrna__exp__param__s" ],
    [ "vrna_fc_s", "group__fold__compound.html#structvrna__fc__s", "group__fold__compound_structvrna__fc__s" ],
    [ "vrna_gr_aux_s", "structvrna__gr__aux__s.html", null ],
    [ "vrna_hc_bp_storage_t", "structvrna__hc__bp__storage__t.html", null ],
    [ "vrna_hc_s", "group__hard__constraints.html#structvrna__hc__s", "group__hard__constraints_structvrna__hc__s" ],
    [ "vrna_hc_up_s", "group__hard__constraints.html#structvrna__hc__up__s", "group__hard__constraints_structvrna__hc__up__s" ],
    [ "vrna_hx_s", "group__struct__utils.html#structvrna__hx__s", null ],
    [ "vrna_md_s", "group__model__details.html#structvrna__md__s", "group__model__details_structvrna__md__s" ],
    [ "vrna_move_s", "group__neighbors.html#structvrna__move__s", "group__neighbors_structvrna__move__s" ],
    [ "vrna_mx_mfe_s", "group__dp__matrices.html#structvrna__mx__mfe__s", "group__dp__matrices_structvrna__mx__mfe__s" ],
    [ "vrna_mx_pf_aux_el_t", "group__loops.html#structvrna__mx__pf__aux__el__t", null ],
    [ "vrna_mx_pf_aux_ml_t", "group__loops.html#structvrna__mx__pf__aux__ml__t", null ],
    [ "vrna_mx_pf_s", "group__dp__matrices.html#structvrna__mx__pf__s", null ],
    [ "vrna_param_s", "group__energy__parameters.html#structvrna__param__s", "group__energy__parameters_structvrna__param__s" ],
    [ "vrna_path_s", "group__direct__paths.html#structvrna__path__s", "group__direct__paths_structvrna__path__s" ],
    [ "vrna_pinfo_s", "group__aln__utils.html#structvrna__pinfo__s", "group__aln__utils_structvrna__pinfo__s" ],
    [ "vrna_sc_bp_storage_t", "structvrna__sc__bp__storage__t.html", null ],
    [ "vrna_sc_motif_s", "structvrna__sc__motif__s.html", null ],
    [ "vrna_sc_s", "group__soft__constraints.html#structvrna__sc__s", "group__soft__constraints_structvrna__sc__s" ],
    [ "vrna_sect_s", "group__data__structures.html#structvrna__sect__s", null ],
    [ "vrna_sol_TwoD_pf_t", "group__kl__neighborhood__pf.html#structvrna__sol__TwoD__pf__t", "group__kl__neighborhood__pf_structvrna__sol__TwoD__pf__t" ],
    [ "vrna_sol_TwoD_t", "group__kl__neighborhood__mfe.html#structvrna__sol__TwoD__t", "group__kl__neighborhood__mfe_structvrna__sol__TwoD__t" ],
    [ "vrna_structured_domains_s", "structvrna__structured__domains__s.html", null ],
    [ "vrna_subopt_sol_s", "structvrna__subopt__sol__s.html", "structvrna__subopt__sol__s" ],
    [ "vrna_unstructured_domain_motif_s", "structvrna__unstructured__domain__motif__s.html", null ],
    [ "vrna_unstructured_domain_s", "group__domains__up.html#structvrna__unstructured__domain__s", "group__domains__up_structvrna__unstructured__domain__s" ]
];

==> ViennaRNA-2.4.14.tar.gz: ViennaRNA-2.4.14/doc/html/annotated_dup.js <==
var annotated_dup =
[
    [ "_struct_en", "struct__struct__en.html", null ],
    [ "constrain", "group__data__structures.html#structconstrain", null ],
    [ "COORDINATE", "group__plotting__utils__deprecated.html#structCOORDINATE", null ],
    [ "duplexT", "group__data__structures.html#structduplexT", null ],
    [ "dupVar", "group__data__structures.html#structdupVar", null ],
    [ "interact", "group__data__structures.html#structinteract", "group__data__structures_structinteract" ],
    [ "LIST", "structLIST.html", null ],
    [ "LST_BUCKET", "structLST__BUCKET.html", null ],
    [ "node", "group__data__structures.html#structnode", null ],
    [ "Postorder_list", "structPostorder__list.html", null ],
    [ "pu_contrib", "group__data__structures.html#structpu__contrib", "group__data__structures_structpu__contrib" ],
    [ "pu_out", "group__data__structures.html#structpu__out", "group__data__structures_structpu__out" ],
    [ "snoopT", "group__data__structures.html#structsnoopT", null ],
    [ "swString", "structswString.html", null ],
    [ "Tree", "structTree.html", null ],
    [ "TwoDfold_vars", "group__kl__neighborhood__mfe.html#structTwoDfold__vars", "group__kl__neighborhood__mfe_structTwoDfold__vars" ],
    [ "TwoDpfold_vars", "structTwoDpfold__vars.html", "structTwoDpfold__vars" ],
    [ "vrna_alignment_s", "group__alphabet__utils.html#structvrna__alignment__s", null ],
    [ "vrna_basepair_s", "group__data__structures.html#structvrna__basepair__s", null ],
    [ "vrna_bp_stack_s", "group__data__structures.html#structvrna__bp__stack__s", null ],
    [ "vrna_color_s", "group__data__structures.html#structvrna__color__s", null ],
    [ "vrna_cpair_s", "group__data__structures.html#structvrna__cpair__s", null ],
    [ "vrna_data_linear_s", "group__data__structures.html#structvrna__data__linear__s", null ],
    [ "vrna_dimer_conc_s", "structvrna__dimer__conc__s.html", "structvrna__dimer__conc__s" ],
    [ "vrna_dimer_pf_s", "group__part__func__global.html#structvrna__dimer__pf__s", "group__part__func__global_structvrna__dimer__pf__s" ],
    [ "vrna_dotplot_auxdata_t", "group__plotting__utils.html#structvrna__dotplot__auxdata__t", null ],
    [ "vrna_elem_prob_s", "group__struct__utils__plist.html#structvrna__elem__prob__s", "group__struct__utils__plist_structvrna__elem__prob__s" ],
    [ "vrna_exp_param_s", "group__energy__parameters.html#structvrna__exp__param__s", "group__energy__parameters_structvrna__exp__param__s" ],
    [ "vrna_fc_s", "group__fold__compound.html#structvrna__fc__s", "group__fold__compound_structvrna__fc__s" ],
    [ "vrna_gr_aux_s", "group__grammar.html#structvrna__gr__aux__s", "group__grammar_structvrna__gr__aux__s" ],
    [ "vrna_hc_bp_storage_t", "structvrna__hc__bp__storage__t.html", null ],
    [ "vrna_hc_s", "group__hard__constraints.html#structvrna__hc__s", "group__hard__constraints_structvrna__hc__s" ],
    [ "vrna_hc_up_s", "group__hard__constraints.html#structvrna__hc__up__s", "group__hard__constraints_structvrna__hc__up__s" ],
    [ "vrna_ht_entry_db_t", "group__hash__table__utils.html#structvrna__ht__entry__db__t", "group__hash__table__utils_structvrna__ht__entry__db__t" ],
    [ "vrna_hx_s", "group__struct__utils__helix__list.html#structvrna__hx__s", null ],
    [ "vrna_md_s", "group__model__details.html#structvrna__md__s", "group__model__details_structvrna__md__s" ],
    [ "vrna_move_s", "group__neighbors.html#structvrna__move__s", "group__neighbors_structvrna__move__s" ],
    [ "vrna_mx_mfe_s", "group__dp__matrices.html#structvrna__mx__mfe__s", "group__dp__matrices_structvrna__mx__mfe__s" ],
    [ "vrna_mx_pf_s", "group__dp__matrices.html#structvrna__mx__pf__s", null ],
    [ "vrna_param_s", "group__energy__parameters.html#structvrna__param__s", "group__energy__parameters_structvrna__param__s" ],
    [ "vrna_path_s", "group__paths.html#structvrna__path__s", "group__paths_structvrna__path__s" ],
    [ "vrna_pinfo_s", "group__aln__utils.html#structvrna__pinfo__s", "group__aln__utils_structvrna__pinfo__s" ],
    [ "vrna_plot_layout_s", "group__plot__layout__utils.html#structvrna__plot__layout__s", null ],
    [ "vrna_plot_options_puzzler_t", "group__plot__layout__utils.html#structvrna__plot__options__puzzler__t", null ],
    [ "vrna_sc_bp_storage_t", "structvrna__sc__bp__storage__t.html", null ],
    [ "vrna_sc_motif_s", "structvrna__sc__motif__s.html", null ],
    [ "vrna_sc_s", "group__soft__constraints.html#structvrna__sc__s", "group__soft__constraints_structvrna__sc__s" ],
    [ "vrna_sect_s", "group__data__structures.html#structvrna__sect__s", null ],
    [ "vrna_sequence_s", "group__alphabet__utils.html#structvrna__sequence__s", "group__alphabet__utils_structvrna__sequence__s" ],
    [ "vrna_sol_TwoD_pf_t", "group__kl__neighborhood__pf.html#structvrna__sol__TwoD__pf__t", "group__kl__neighborhood__pf_structvrna__sol__TwoD__pf__t" ],
    [ "vrna_sol_TwoD_t", "group__kl__neighborhood__mfe.html#structvrna__sol__TwoD__t", "group__kl__neighborhood__mfe_structvrna__sol__TwoD__t" ],
    [ "vrna_structured_domains_s", "structvrna__structured__domains__s.html", null ],
    [ "vrna_subopt_sol_s", "structvrna__subopt__sol__s.html", "structvrna__subopt__sol__s" ],
    [ "vrna_unstructured_domain_motif_s", "structvrna__unstructured__domain__motif__s.html", null ],
    [ "vrna_unstructured_domain_s", "group__domains__up.html#structvrna__unstructured__domain__s", "group__domains__up_structvrna__unstructured__domain__s" ]
];
